@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  Copyright 2013-2015  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
@@ -27,8 +27,7 @@
 class ResourceManager;
 class Course;
 
-class ResourcesDialogPage :
-    public QWidget
+class ResourcesDialogPage : public QWidget
 {
     Q_OBJECT
 
@@ -36,7 +35,7 @@ public:
     explicit ResourcesDialogPage(ResourceManager *resourceMgr);
     virtual ~ResourcesDialogPage();
 
-public slots:
+public Q_SLOTS:
     void saveSettings();
     void loadSettings();
 
